<!DOCTYPE html>
<?php
include '../etc/asceds.php';
include '../etc/config.php';
?>

<html>
  <head>
    <meta name="author" content="Florin Manolache">
    <title>ASCEDS Certificate management</title>
    <link rel="stylesheet" href="css/cert.css">
  </head>

<body>

<div id="main">

<article>

<?php
include 'navi.php';
?>

<?php 
if (file_exists('cert/.htpasswd')) {
echo '<p style="margin-top:32px;">';
echo 'User access is based on Apache simple authentication.<br>';
echo 'Please contact the site admin to get an account.</p>';
}
?>


<p class="asceds">ASCEDS certificate management system</p>

<?php
include 'custom.php';
?>


<h1> What is ASCEDS </h1>

Automated SSL Certificate Distribution System (ASCEDS) 
is a distribution system for certificates 
which can be obtained from a provider offering an ACME interface. 
The system defines a site containing:
<ul>
<li> one certificate manager
which can get SSL certificates for wilcard 
hostnames in a set of domains through certbot;
<li> a set of managed clients getting automatic certificate renewal or
  reconfiguration of SANs; services using certificates are 
  reconfigured/restarted automatically upon renewal;
<li> a web interface handling certificates for managed or unmanaged
  clients.
</ul>
ASCEDS consists into a set of shell scripts; 
the web interface is written in PHP. <br>
Each script has a help option '-h'.<br>
The details are described in the 
<a href="public/asceds.pdf">ASCEDS whitepaper</a>.
It can be downloaded after login, or by installing ASCEDS.
<p>
ASCEDS is released under GPLv2 or any later version.<br>
The certificate manager was tested on Ubuntu 18.04 and newer versions.<br>
Currently, managed client packages are available for: Ubuntu, Arch Linux,
Debian, Raspbian, CentOS 7. 
</p>

<h1>Quick start of a new site</h1>

<p>
<span class="bold">Step 1: install ASCEDS on all the computers of the site 
(certificate manager and managed clients)</span>
</p>

<p>
<span class="bold">Step 2: configure the certificate manager</span><br>
On the certificate manager:
<ul>
<li> install and configure dependencies: snap, certbot, apache2/httpd
<li> initialize the certificate manager: <br>
     <em> asceds-certmanager-setup [-s certmanager] </em>
<li> configure the client (shown in Step 3 below) using the root/sudo choice
<li> customize the website:
<ul> 
  <li> edit the apache2/httpd site configuration file typically in
    /etc/${ASCEDSWEBEXEC}/sites-available/asceds.conf;
  <li> decide on the authentication and add the right .htaccess
    to /usr/share/asceds/html/cert/
    (see examples in /usr/share/doc/asceds/examples/site-*);
  <li> edit the web php configuration in /usr/share/asceds/etc/config.php
    (see examples in /usr/share/doc/asceds/examples/php-etc);
  <li> enable the website on the webserver: e.g. a2ensite asceds on 
    Debian derivatives;
</ul>
<li> add authorized users: <em>asceds-web-user -a username</em>
</ul>
</p>


<p>
<span class="bold">Step 3: initialize the managed clients</span><br>
On each managed client:
<ul>
<li> get info: certificate manager name, root/sudo account access, 
            account on the web interface of the certificate manager
<li> prerequisites: client should be connected to the network,
            have DNS record, public IP address,
            and the domain should be served by the certificate manager
<li> connect to the certificate manager and follow instructions: <br>
     <em>asceds-init [-s cert_manager]</em><br>
     when prompted, select the services using SSL certificates.
</ul>
</p>

<p>
<span class="bold">Step 4: the unmanaged clients</span><br>
For each unmanaged client:
<ul>
<li> login to the certificate manager web interface;
<li> request a certificate;
<li> download the certificate into the client and reconfigure the services.
</ul>
</p>
</article>

<aside>

<img src="figs/ASCEDSarch.png" alt="ASCEDS Architecture"
style="width: 20vw; min-width: 200px;">

<?php 
if (file_exists('public/asceds-site.conf')) {
echo '<span class="alignright">';
echo '<a href="public/asceds-site.conf"class="button" download>';
echo 'Site configuration file</a>';
echo '</span>';
}
?>

<p> <span class="bold"> ASCEDS architecture: </span>
an ASCEDS site consists of a certificate manager which is authorized to
get certificates for a set of domains 
based on secret tokens issued by a CA.<br>
The certificate manager has three kinds of clients:
<ul>
<li> <span class="bold">fully managed: </span> 
the certificate update process happens automatically;
<li><span class="bold">privately managed: </span>
client needs to be put in full ASCEDS access mode to
propagate cert files (e.g. pi-kvm);
<li> <span class="bold">unmanaged: </span>
no ASCEDS installed on the client; cert files and updates are propagated 
by hand by the sysadmin of the client (e.g. NAS, printer, switch,
Windows/MacOS);
</ul>
</p>

<p> 
For <span class="bold">unmanaged</span> clients, 
certificate files are generated and offered for download.
For <span class="bold">managed</span> clients, 
certificate files are generated and propagated to the client.
</p>
<p>
The certificate request website structure is the following:<br>
<img src="figs/WebsiteStructure.png" alt="Website Structure"
style="width: 30vw; min-width: 200px;">


</p>


</aside>


</div>

<?php
include 'footer.php';
?>

</body>
</html>